# Model Reference

## Geospacial model objects

::: geo_track_analyzer.model.Position2D
::: geo_track_analyzer.model.Position3D
::: geo_track_analyzer.model.ElevationMetrics
::: geo_track_analyzer.model.SegmentOverview
::: geo_track_analyzer.model.SegmentOverlap
::: geo_track_analyzer.model.PointDistance

## Other model objects

::: geo_track_analyzer.model.ZoneInterval
::: geo_track_analyzer.model.Zones